==> nextcloud-23.0.9.tgz: nextcloud/apps/photos/l10n/nl.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Foto's",
    "Your memories under your control" : "Jouw herinneringen onder jouw beheer",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "People" : "Mensen",
    "Folders" : "Mappen",
    "Favorites" : "Favorieten",
    "On this day" : "Vandaag",
    "Shared with you" : "Met je gedeeld",
    "Tags" : "Tags",
    "Locations" : "Locaties",
    "Back" : "Terug",
    "Save" : "Opslaan",
    "Open the full size \"{name}\" image" : "Open het \"{name}\" beeld in originele grootte",
    "Upload from computer" : "Uploaden vanaf computer",
    "Open the \"{name}\" sub-directory" : "Open de \"{name}\" map",
    "Back to {folder}" : "Terug naar {folder}",
    "Share this folder" : "Deze map delen",
    "_{years} year ago_::_{years} years ago_" : ["{years} jaar geleden","{years} jaren geleden"],
    "Enable squared photos view" : "Inschakelen vierkante foto overzicht",
    "View" : "Bekijken",
    "An error occurred" : "Er heeft een fout opgetreden",
    "Favorite" : "Favoriet",
    "Remove from favorites" : "Verwijder uit favorieten",
    "This folder does not exist" : "Deze map bestaat niet",
    "No photos in here" : "Geen foto's hier",
    "No tags yet" : "Nog geen labels",
    "Photos with tags will show up here" : "Gelabelde foto's worden hier getoond",
    "Add" : "Toevoegen",
    "Download" : "Download",
    "Delete selection" : "Verwijder selectie",
    "Delete" : "Verwijder",
    "Tagged photos" : "Gelabelde foto's",
    "Your photos" : "Je foto's",
    "Your videos" : "Je video's",
    "Your folders" : "Je mappen",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/photos/l10n/nl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Openbare Link",
    "Photos" : "Foto's",
    "Your memories under your control" : "Jouw herinneringen onder jouw beheer",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "People" : "Mensen",
    "Folders" : "Mappen",
    "Favorites" : "Favorieten",
    "On this day" : "Op deze dag",
    "Shared with you" : "Met je gedeeld",
    "Tags" : "Tags",
    "Locations" : "Locaties",
    "Back" : "Terug",
    "Save" : "Opslaan",
    "Copy public link" : "Kopieer openbare link",
    "An error occurred" : "Er heeft een fout opgetreden",
    "Open the full size \"{name}\" image" : "Open het \"{name}\" beeld in originele grootte",
    "Open the \"{name}\" sub-directory" : "Open de \"{name}\" map",
    "Back to {folder}" : "Terug naar {folder}",
    "Share this folder" : "Deze map delen",
    "_{years} year ago_::_{years} years ago_" : ["{years} jaar geleden","{years} jaren geleden"],
    "Enable squared photos view" : "Inschakelen vierkante foto overzicht",
    "View" : "Bekijken",
    "Favorite" : "Favoriet",
    "Remove from favorites" : "Verwijder uit favorieten",
    "This folder does not exist" : "Deze map bestaat niet",
    "No photos in here" : "Geen foto's hier",
    "Shared albums" : "Gedeelde albums",
    "No tags yet" : "Nog geen labels",
    "Photos with tags will show up here" : "Gelabelde foto's worden hier getoond",
    "Add" : "Toevoegen",
    "Delete selection" : "Verwijder selectie",
    "Tagged photos" : "Gelabelde foto's",
    "Your photos" : "Je foto's",
    "Your videos" : "Je video's",
    "Your folders" : "Je mappen",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");
